# Changelog

## [v0.3.0](https://github.com/UAL-ODIS/ldcoolp-figshare/tree/v0.3.0) (2021-06-08)

**Implemented enhancements:**
 -  Update use of redata.commons to include process option [#24](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/24)

**Closed issues:**
 -  Update use of redata.commons to include process option [#23](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/23)


## [v0.2.2](https://github.com/UAL-ODIS/ldcoolp-figshare/tree/v0.2.2) (2021-06-03)

**Implemented enhancements:**
 - For get_curation_list method, allow for pending selection [#21](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/21)
 
**Fixed bugs:**
 - Remove GitHub badges from RTDs [#20](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/20)

**Closed issues:**
 - For get_curation_list method, allow for pending selection [#19](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/19)

**Merged pull requests:**
 - Remove GitHub badges from RTDs [#22](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/22)


## [v0.2.0](https://github.com/UAL-ODIS/ldcoolp-figshare/tree/HEAD) (2021-05-24)

**Implemented enhancements:**
 - Prepare code for PyPI packaging; Add CHANGELOG [#15](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/15)

**Closed issues:**
 - Update README.md with RTDs information and links [#12](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/12)
 - Prepare code for PyPI packaging [#4](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/4)
 - Add CHANGELOG [#14](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/14)

**Merged pull requests:**
 - Update README.md with RTDs information and links [#13](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/13)


## [v0.1.0](https://github.com/UAL-ODIS/ldcoolp-figshare/tree/v0.1.0) (2021-05-20)

**Implemented enhancements:**
 - Add Sphinx documentation and publish to ReadTheDocs [#11](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/11)

**Closed issues:**
 - Add Sphinx documentation and publish to ReadTheDocs [#10](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/10)


## [v0.0.3](https://github.com/UAL-ODIS/ldcoolp-figshare/tree/v0.0.3) (2021-05-18)

**Closed issues:**
 - Refactor FigshareInstituteAdmin for general use [#7](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/7)
 - Add GitHub action to create releases with v* tags [#9](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/9)

**Merged pull requests:**
 - Refactor FigshareInstituteAdmin for general use [#8](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/8)


## [v0.0.2](https://github.com/UAL-ODIS/ldcoolp-figshare/tree/v0.0.2) (2021-05-18)

**Implemented enhancements:**
 - Include issue_request from redata-commons [#6](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/6)

**Closed issues:**
 - Chore: Add README.md, LICENSE, and .gitignore files [#3](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/3)
 - Include issue_request from redata-commons [#5](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/5)


## [v0.0.1](https://github.com/UAL-ODIS/ldcoolp-figshare/tree/v0.0.1) (2021-05-14)

**Closed issues:**
 - Reorganize codebase for easier packaging [#1](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/1)

**Merged pull requests:**
 - Reorganize codebase for easier packaging [#2](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/2)


<!-- TEMPLATE
## [vXX.YY.ZZ](https://github.com/UAL-ODIS/ldcoolp-figshare/tree/vXX.YY.ZZ) (YYYY-MM-DD)

**Implemented enhancements:**
 - `______` [#XX](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/XX)

**Fixed bugs:**
 - `______` [#XX](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/XX)

**Closed issues:**
 - `______` [#XX](http://github.com/UAL-ODIS/ldcoolp-figshare/issues/XX)

**Merged pull requests:**
 - `______` [#XX](http://github.com/UAL-ODIS/ldcoolp-figshare/pull/XX)

-->
